Changelog
=========

- new MAJOR version for incompatible API changes,
- new MINOR version for added functionality in a backwards compatible manner
- new PATCH version for backwards compatible bug fixes

v1.0.1.2
---------
2022-06-02: update to github actions checkout@v3 and setup-python@v3

v1.0.1
--------
2022-03-29: remedy mypy Untyped decorator in cli

v1.0.0
---------
2022-03-25:
 - initial pypi release
 - update documentation and tests
 - list ./dist dir if existing

v0.0.1
---------
2021-08-23: initial release
